@@ -7,6 +7,7 @@ use FindBin qw/$Bin/;
 use lib "$Bin/../lib";
 use WWW::ModulrFinance;
 use Data::Dumper;
+use JSON;
 
 die "ENV MODULR_APIKEY" unless $ENV{MODULR_APIKEY};
 die "ENV MODULR_HMAC_SECRET" unless $ENV{MODULR_HMAC_SECRET};
@@ -19,8 +20,10 @@ my $res = $modulr->get_accounts;
 say Dumper(\$res);
 
 # my $res = $modulr->create_customer_account('C1200J1K', {
-#     "currency" => "GBP",
-#     "externalReference" => "TEST",
-#     "productCode" => "TESTPRODUCT"
+#     account => {
+#         "currency" => "GBP",
+#         "externalReference" => "TEST",
+#         "productCode" => "TESTPRODUCT"
+#     }
 # });
 # say Dumper(\$res);
\ No newline at end of file
